@@ -1,5 +1,5 @@
 
-# $rcs = ' $Id: Session.pm,v 1.62 2010-06-29 03:03:44 Martin Exp $ ' ;
+# $rcs = ' $Id: Session.pm,v 1.64 2014-09-09 03:07:22 Martin Exp $ ' ;
 
 =head1 COPYRIGHT
 
@@ -63,7 +63,7 @@ use constant DEBUG_WATCH => 0;
 use constant DEBUG_READ_LOCAL_FILES => 0;
 
 our
-$VERSION = do { my @r = (q$Revision: 1.62 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
+$VERSION = do { my @r = (q$Revision: 1.64 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
 
 sub _debug
   {
@@ -131,12 +131,12 @@ sub signin
   my $self = shift;
   my $sUserID = $self->{_user} || '';
   my $sPassword = $self->{_pass} || '';
-  DEBUG_FUNC && print STDERR " + Ebay::Session::signin($sUserID)\n";
-  print STDERR " + signin($sUserID,$sPassword)\n" if DEBUG_FETCH;
+  DEBUG_FUNC && print STDERR " DDD Ebay::Session::signin($sUserID)\n";
+  print STDERR " DDD signin($sUserID,$sPassword)\n" if DEBUG_FETCH;
   if (! exists($hssPasswords{$sUserID}))
     {
     # Get the sign-in page and parse it:
-    print STDERR " +   fetching ebay sign-in page...\n" if DEBUG_FETCH;
+    print STDERR " DDD   fetching ebay sign-in page...\n" if DEBUG_FETCH;
     # my $sPage = $self->fetch_any_ebay_page('http://cgi.ebay.com/aw-cgi/eBayISAPI.dll?SignIn', 'signin', 'ignore-refresh');
     my $sPage = $self->fetch_any_ebay_page('http://signin.ebay.com/ws/eBayISAPI.dll?SignIn&ssPageName=h:h:sin:US', 'signin', 'ignore-refresh');
     # http://signin.ebay.com/ws/eBayISAPI.dll?SignIn&ssPageName=h:h:sin:US&ru=http%3A//my.ebay.com/ws/ebayISAPI.dll%3FMyeBay%26CurrentPage%3DMyeBayAllSelling
@@ -164,7 +164,7 @@ sub fetch_any_ebay_page
   # Optional arg3 == whether to ignore meta-refresh tags (default is
   # to follow redirects):
   my $iIgnoreRefresh = shift() || 0;
-  DEBUG_FUNC && print STDERR " + Ebay::Session::fetch_any($sName)\n";
+  DEBUG_FUNC && print STDERR " DDD Ebay::Session::fetch_any($sName)\n";
   my $fname = "Pages/$sName.html";
   my $sPage = '';
   if (DEBUG_READ_LOCAL_FILES && ($sName ne '') && -f $fname)
@@ -179,7 +179,7 @@ sub fetch_any_ebay_page
     close DBG;
     return $sPage;
     } # if
-  print STDERR " + in fetch_any_ebay_page, oReq is $oReq\n" if DEBUG_FETCH;
+  print STDERR " DDD in fetch_any_ebay_page, oReq is $oReq\n" if DEBUG_FETCH;
   my $ref = ref $oReq;
   unless ((defined $ref) && ($ref =~ m!HTTP::!))
     {
@@ -193,23 +193,23 @@ sub fetch_any_ebay_page
   my $sReq = $oReq->as_string;
   if ($sName ne '')
     {
-    print STDERR " +   the HTTP::Request for $sName is $sReq" if DEBUG_FETCH;
+    print STDERR " DDD   the HTTP::Request for $sName is $sReq" if DEBUG_FETCH;
     } # if
   $self->response($self->user_agent->request($oReq));
   my $sRes = $self->response->as_string;
-  DEBUG_FETCH && print STDERR " +   the HTTP::Response for $sName is ==========$sRes==========";
+  DEBUG_FETCH && print STDERR " DDD   the HTTP::Response for $sName is ==========$sRes==========";
   my $sURLprev = '';
  OBJECT_MOVED:
   while ($self->response->code == 302)
     {
-    print STDERR " +     server says: Object Moved\n" if DEBUG_FETCH;
+    print STDERR " DDD     server says: Object Moved\n" if DEBUG_FETCH;
     $sReq .= "<!-- 302 object moved -->\n";
     $sURLprev = $sURL;
     $sURL = $self->response->header('Location');
     $oReq = GET $sURL;
     $oReq->referer($sURLprev);
     $self->cookie_jar->add_cookie_header($oReq);
-    print STDERR " +   the new HTTP::Request for $sName is ", $oReq->as_string if DEBUG_FETCH;
+    print STDERR " DDD   the new HTTP::Request for $sName is ", $oReq->as_string if DEBUG_FETCH;
     $sReq .= $oReq->as_string;
     $self->response($self->user_agent->request($oReq));
     } # while
@@ -219,11 +219,11 @@ sub fetch_any_ebay_page
     $sURLprev = $sURL;
     $sURL = $1;
     $sURL =~ s!&amp;!&!g;
-    print STDERR " +     server says: Meta-Refresh to $sURL\n" if DEBUG_FETCH;
+    print STDERR " DDD     server says: Meta-Refresh to $sURL\n" if DEBUG_FETCH;
     $oReq = GET $sURL;
     $oReq->referer($sURLprev);
     $self->cookie_jar->add_cookie_header($oReq);
-    print STDERR " +   the new HTTP::Request for $sName is ", $oReq->as_string if DEBUG_FETCH;
+    print STDERR " DDD   the new HTTP::Request for $sName is ", $oReq->as_string if DEBUG_FETCH;
     $sReq .= "<!-- 200 meta refresh -->\n";
     $sReq .= $oReq->as_string;
     $self->response($self->user_agent->request($oReq));
@@ -254,19 +254,19 @@ sub fetch_any_ebay_page
       print PAGE "<!-- The response headers for this page are:\n$sRes\n-->\n\n";
       print PAGE $sPage;
       close PAGE;
-      print STDERR " + eBay GET $sName saved in $fname1\n" if DEBUG_FETCH;
+      print STDERR " DDD eBay GET $sName saved in $fname1\n" if DEBUG_FETCH;
       } # if
-    print STDERR " + parsing ebay sign-in page...\n" if DEBUG_FETCH;
+    print STDERR " DDD parsing ebay sign-in page...\n" if DEBUG_FETCH;
     # Parse the <FORM> elements:
     my @aoForm = HTML::Form->parse($sPage, $self->response->base);
-    # The sign-in form is the first one on the page:
+    # As of August 2014, the sign-in form is the first one on the page:
     my $oForm = $aoForm[0];
     unless (ref $oForm)
       {
-      print STDERR " --- eBay sign-in page's <FORM> was not valid?\n" if DEBUG_FETCH;
+      print STDERR " EEE eBay sign-in page contained no <FORM> element!\n" if DEBUG_FETCH;
       return undef;
       } # unless
-    print STDERR " +   got a FORM...\n" if DEBUG_FETCH;
+    print STDERR " DDD   got a FORM...\n" if DEBUG_FETCH;
     # Insert the user's values:
     $oForm->value('userid', $self->{_user});
     $oForm->value('pass', $self->{_pass});
@@ -276,8 +276,8 @@ sub fetch_any_ebay_page
     $oReq = $oForm->click;
     $oReq->referer($sURLprev);
     $sURLprev = $sURL;
-    print STDERR " +   CLICK is ", Dumper($oReq) if DEBUG_FETCH;
-    print STDERR " + submitting password to ebay...\n" if DEBUG_FETCH;
+    print STDERR " DDD   CLICK is ", Dumper($oReq) if DEBUG_FETCH;
+    print STDERR " DDD submitting password to ebay...\n" if DEBUG_FETCH;
     goto REQUEST_READY;
     } # if we got a sign-in page
   elsif (($sPage =~ m!"AdultLogin"!)
@@ -292,7 +292,7 @@ sub fetch_any_ebay_page
       print PAGE "<!-- The response headers for this page are:\n$sRes\n-->\n\n";
       print PAGE $sPage;
       close PAGE;
-      print STDERR " + eBay GET $sName saved in $fname1\n" if DEBUG_FETCH;
+      print STDERR " DDD eBay GET $sName saved in $fname1\n" if DEBUG_FETCH;
       } # if
     # We need to accept the "Mature" disclaimer before we get to see
     # the requested page.  Parse the <FORM> elements:
@@ -304,13 +304,13 @@ sub fetch_any_ebay_page
       print STDERR " --- eBay adult-consent page's <FORM> was not valid?\n" if DEBUG_FETCH;
       return undef;
       } # unless
-    print STDERR " +   got a FORM...\n" if DEBUG_FETCH;
+    print STDERR " DDD   got a FORM...\n" if DEBUG_FETCH;
     # Submit the form and get our cookie:
     $oReq = $oForm->click;
     $oReq->referer($sURLprev);
     $sURLprev = $sURL;
-    print STDERR " + giving adult-consent to ebay...\n" if DEBUG_FETCH;
-    print STDERR " +   CLICK is ", Dumper($oReq) if DEBUG_FETCH;
+    print STDERR " DDD giving adult-consent to ebay...\n" if DEBUG_FETCH;
+    print STDERR " DDD   CLICK is ", Dumper($oReq) if DEBUG_FETCH;
     goto REQUEST_READY;
     }
   else
@@ -323,7 +323,7 @@ sub fetch_any_ebay_page
       print PAGE "<!-- The response headers for this page are:\n$sRes\n-->\n\n";
       print PAGE $sPage;
       close PAGE;
-      print STDERR " + eBay GET $sName saved in $fname\n" if DEBUG_FETCH;
+      print STDERR " DDD eBay GET $sName saved in $fname\n" if DEBUG_FETCH;
       } # if
     } # else
   return $sPage;
@@ -372,7 +372,7 @@ sub clear_errors
 
 sub _epoch_of_date
   {
-  return &UnixDate(&ParseDate(shift), '%s');
+  return UnixDate(&ParseDate(shift), '%s');
   } # _epoch_of_date
 
 =item selling_page
@@ -391,7 +391,7 @@ sub selling_page
     } # if
   my $sUserID = $self->{_user};
   my $sPasswordEncrypted = $self->signin();
-  print STDERR " + sPasswordEncrypted is ===$sPasswordEncrypted===\n" if DEBUG_FETCH;
+  print STDERR " DDD sPasswordEncrypted is ===$sPasswordEncrypted===\n" if DEBUG_FETCH;
   # my $sURL = qq{http://cgi6.ebay.com/aw-cgi/eBayISAPI.dll?MfcISAPICommand=MyeBayItemsSelling&userid=$sUserID&pass=$sPasswordEncrypted&dayssince=30};
   my $sURL = qq{http://cgi6.ebay.com/aw-cgi/ebayISAPI.dll?MyeBayItemsSelling&userid=$sUserID&pass=$sPasswordEncrypted&first=N&sellerSort=3&bidderSort=3&watchSort=3&dayssince=30};
   $sURL = qq{http://my.ebay.com/ws/ebayISAPI.dll?MyeBay&userid=$sUserID&pass=$sPasswordEncrypted&first=N&sellerSort=3&bidderSort=3&watchSort=3&dayssince=30};
@@ -420,8 +420,8 @@ sub watchlist_auctions
     print PAGE $sPage;
     close PAGE or warn;
     } # if
-  _debug " +   start parsing webpage...\n" if DEBUG_WATCH;
-  &Date_Init('TZ=US/Pacific');
+  _debug " DDD   start parsing webpage...\n" if DEBUG_WATCH;
+  Date_Init('TZ=US/Pacific');
   # Our return value, a list of WWW::Search::Result objects:
   my @aoWSR;
 
@@ -538,8 +538,8 @@ sub selling_auctions
     print PAGE $sPage;
     close PAGE or warn;
     } # if
-  _debug " +   start parsing webpage...\n" if DEBUG_SELLING;
-  &Date_Init('TZ=US/Pacific');
+  _debug " DDD   start parsing webpage...\n" if DEBUG_SELLING;
+  Date_Init('TZ=US/Pacific');
   # Our return value, a list of WWW::Ebay::Listing objects:
   my @aoWEL;
 
@@ -562,14 +562,14 @@ sub selling_auctions
                                      );
     if (ref $oAselling)
       {
-      DEBUG_SELLING && _debug(" +   found <SPAN> for SELLING section: ", $oAselling->as_HTML, "\n");
+      DEBUG_SELLING && _debug(" DDD   found <SPAN> for SELLING section: ", $oAselling->as_HTML, "\n");
       $oAselling = $oAselling->look_up(_tag => 'td');
       last PARSE_SELLING_SECTION if ! ref($oAselling);
-      DEBUG_SELLING && _debug(" +     parent is ==", $oAselling->as_HTML, "==\n");
+      DEBUG_SELLING && _debug(" DDD     parent is ==", $oAselling->as_HTML, "==\n");
       my $s = $oAselling->as_text;
       $s =~ m!\s+\(\s*(\d+)\s+ITEM!i;
       $iCount = $1 || 0;
-      print STDERR " +   there should be $iCount SELLING auctions\n" if DEBUG_SELLING;
+      print STDERR " DDD   there should be $iCount SELLING auctions\n" if DEBUG_SELLING;
       } # if
     else
       {
@@ -588,7 +588,7 @@ sub selling_auctions
       last PARSE_SELLING_SECTION;
       } # if
     my @asColumns = qw( spacer price bids bidder watchers questions time_left );
-    DEBUG_SELLING && _debug(" +   selling <TABLE> is ==", $oTable->as_HTML, "==\n");
+    DEBUG_SELLING && _debug(" DDD   selling <TABLE> is ==", $oTable->as_HTML, "==\n");
     my @aoTR = $oTable->look_down('_tag' => 'tr');
     # Throw out the header row:
     shift @aoTR;
@@ -600,7 +600,7 @@ sub selling_auctions
       # Got a row containing an auction.  Actually they are pairs of
       # rows; one row has the auction title, the next row has all the
       # details.
-      DEBUG_SELLING && _debug(" +   <TR> containing selling auction title ==", $oTR->as_HTML, "==\n");
+      DEBUG_SELLING && _debug(" DDD   <TR> containing selling auction title ==", $oTR->as_HTML, "==\n");
       my $oA = $oTR->look_down('_tag' => 'a',
                                sub
                                  {
@@ -623,7 +623,7 @@ sub selling_auctions
       $oWEL->title($sTitle);
       $oWEL->id($iItem);
       $oWEL->status->listed('yes');
-      print STDERR " +     title ==$sTitle==\n" if DEBUG_SELLING;
+      print STDERR " DDD     title ==$sTitle==\n" if DEBUG_SELLING;
       # Go to the next row, where we should find the auction details:
       $oTR = $oTR->right; # shift @aoTR;
       if (! ref($oTR))
@@ -631,7 +631,7 @@ sub selling_auctions
         $self->_add_error("Did not find slave <TR> for ITEM.  ");
         next TR;
         } # if
-      DEBUG_SELLING && _debug(" +   <TR> containing selling auction details ==", $oTR->as_HTML, "==\n");
+      DEBUG_SELLING && _debug(" DDD   <TR> containing selling auction details ==", $oTR->as_HTML, "==\n");
       my @aoTD = $oTR->look_down('_tag' => 'td');
  SELLING_COLUMN:
       foreach my $sCol (@asColumns)
@@ -682,9 +682,9 @@ sub selling_auctions
           $sDate =~ s!h! hours!;
           $sDate =~ s!m! minutes!;
           my $date = DateCalc('now', " + $sDate");
-          my $sDateEnd = &_epoch_of_date($date);
+          my $sDateEnd = _epoch_of_date($date);
           $oWEL->dateend($sDateEnd);
-          print STDERR " +   end date: raw ==$sDateRaw== cooked ==$sDate== date==$date==\n" if DEBUG_SELLING;
+          print STDERR " DDD   end date: raw ==$sDateRaw== cooked ==$sDate== date==$date==\n" if DEBUG_SELLING;
           }
         } # foreach SELLING_COLUMN
       push @aoWEL, $oWEL;
@@ -716,8 +716,8 @@ sub sold_auctions
     print PAGE $sPage;
     close PAGE or warn;
     } # if
-  _debug " +   start parsing webpage...\n" if DEBUG_SOLD;
-  &Date_Init('TZ=US/Pacific');
+  _debug " DDD   start parsing webpage...\n" if DEBUG_SOLD;
+  Date_Init('TZ=US/Pacific');
   # Our return value, a list of WWW::Ebay::Listing objects:
   my $oTree;
   if (ref $self->{_selling_tree})
@@ -746,14 +746,14 @@ sub sold_auctions
                               );
     if (ref $oA)
       {
-      DEBUG_SOLD && _debug(" +   found <SPAN> for SOLD section: ", $oA->as_HTML, "\n");
+      DEBUG_SOLD && _debug(" DDD   found <SPAN> for SOLD section: ", $oA->as_HTML, "\n");
       $oA = $oA->parent;
       my $s = $oA->as_text;
       $iCount = -1;
       if ($s =~ m!\(\s*(\d+)\s+ITEM!i)
         {
         $iCount = $1;
-        DEBUG_SOLD && _debug(" +   there should be $iCount sold auctions\n");
+        DEBUG_SOLD && _debug(" DDD   there should be $iCount sold auctions\n");
         } # if
       } # if
     else
@@ -770,7 +770,7 @@ sub sold_auctions
       $self->_add_error("Did not find <TABLE> for SOLD section.  ");
       last PARSE_SOLD_SECTION;
       } # if
-    # print STDERR " +   sold <TABLE> is ==", $oTable->as_HTML, "==\n" if DEBUG_SOLD;
+    # print STDERR " DDD   sold <TABLE> is ==", $oTable->as_HTML, "==\n" if DEBUG_SOLD;
     my @aoTR = $oTable->look_down(_tag => 'tr',
                                   bgcolor => '#f4f4f4',
                                  );
@@ -782,7 +782,7 @@ sub sold_auctions
       # Got a row containing an auction.  Actually they are groups of
       # rows; one row has the buyer's ID, the next rows have all the
       # auctions that person won.
-      _debug(" +   <TR> containing seller ==", $oTR->as_HTML, "==\n") if (2 < DEBUG_SOLD);
+      _debug(" DDD   <TR> containing seller ==", $oTR->as_HTML, "==\n") if (2 < DEBUG_SOLD);
       my @aoTD = $oTR->look_down(_tag => 'td');
       # Column 1 = checkbox:
       $oTD = shift @aoTD;
@@ -802,7 +802,7 @@ sub sold_auctions
       $oWEL->status->ended('yes');
       # Next column = quantity:
       $oTD = shift @aoTD;
-      DEBUG_SOLD && _debug(" +   quantity <TD> ==", $oTD->as_HTML, "==\n");
+      DEBUG_SOLD && _debug(" DDD   quantity <TD> ==", $oTD->as_HTML, "==\n");
       # next Column = Bid Price
       $oTD = shift @aoTD;
       if (! ref($oTD))
@@ -810,21 +810,21 @@ sub sold_auctions
         $self->_add_error("Did not find <TD> for SOLD ITEM end price.  ");
         next SOLD_TR;
         } # if
-      DEBUG_SOLD && _debug(" +     <TD> containing EndPrice ==", $oTD->as_HTML, "==\n");
+      DEBUG_SOLD && _debug(" DDD     <TD> containing EndPrice ==", $oTD->as_HTML, "==\n");
       $s = $oTD->as_text;
-      print STDERR " +     raw End Price is ==$s==\n" if DEBUG_SOLD;
+      print STDERR " DDD     raw End Price is ==$s==\n" if DEBUG_SOLD;
       $s =~ tr!.0123456789!!dc;
       # Convert dollars to cents:
       my $iBidCents = int((0.005 + $s) * 100);
-      print STDERR " +     Bid Cents is ==$iBidCents==\n" if DEBUG_SOLD;
+      print STDERR " DDD     Bid Cents is ==$iBidCents==\n" if DEBUG_SOLD;
       $oWEL->bidmax($iBidCents);
       # next Column = Total Price with shipping.  If the buyer has not
       # done checkout (and the seller has not sent an invoice), this
       # will be '--'.
       $oTD = shift @aoTD;
-      DEBUG_SOLD && _debug(" +   <TD> of total price ==", $oTD->as_HTML, "==\n");
+      DEBUG_SOLD && _debug(" DDD   <TD> of total price ==", $oTD->as_HTML, "==\n");
       $s = $oTD->as_text || '';
-      print STDERR " +     raw Total Price is ==$s==\n" if DEBUG_SOLD;
+      print STDERR " DDD     raw Total Price is ==$s==\n" if DEBUG_SOLD;
       if ($s eq '--')
         {
         $oWEL->shipping('unknown');
@@ -839,7 +839,7 @@ sub sold_auctions
           } # if
         # Convert dollars to cents:
         my $iTotalCents = int((0.005 + $s) * 100);
-        print STDERR " +     Total Cents is ==$iTotalCents==\n" if DEBUG_SOLD;
+        print STDERR " DDD     Total Cents is ==$iTotalCents==\n" if DEBUG_SOLD;
         my $iShippingCents = $iTotalCents - $iBidCents;
         $oWEL->shipping($iShippingCents);
         } # else
@@ -849,10 +849,10 @@ sub sold_auctions
         {
         next SOLD_TR;
         } # if
-      DEBUG_SOLD && _debug(" +   <TR> of next row ==", $oTR->as_HTML, "==\n");
+      DEBUG_SOLD && _debug(" DDD   <TR> of next row ==", $oTR->as_HTML, "==\n");
       $oA = $oTR->look_down(_tag => 'a');
       next SOLD_TR unless ref $oA;
-      DEBUG_SOLD && _debug(" +   <A> of title ==", $oA->as_HTML, "==\n");
+      DEBUG_SOLD && _debug(" DDD   <A> of title ==", $oA->as_HTML, "==\n");
       my $sTitle = $oA->as_text;
       $sTitle =~ s![\s\t\r\n]+\Z!!;
       $oWEL->title($sTitle);
@@ -890,8 +890,8 @@ sub unsold_auctions
     print PAGE $sPage;
     close PAGE or warn;
     } # if
-  _debug " +   start parsing webpage...\n" if DEBUG_UNSOLD;
-  &Date_Init('TZ=US/Pacific');
+  _debug " DDD   start parsing webpage...\n" if DEBUG_UNSOLD;
+  Date_Init('TZ=US/Pacific');
   # Our return value, a list of WWW::Ebay::Listing objects:
   my @aoWEL;
 
@@ -913,11 +913,11 @@ sub unsold_auctions
                                      );
     if (ref $oAunsold)
       {
-      print STDERR " +   found <A> for UNSOLD section: ", $oAunsold->as_HTML, "\n" if DEBUG_UNSOLD;
+      print STDERR " DDD   found <A> for UNSOLD section: ", $oAunsold->as_HTML, "\n" if DEBUG_UNSOLD;
       my $s = $oAunsold->as_text;
       $s =~ m!\(\s*(\d+)\s+Items?!;
       $iCount = $1 || 0;
-      print STDERR " +   there should be $iCount UNSOLD auctions\n" if DEBUG_UNSOLD;
+      print STDERR " DDD   there should be $iCount UNSOLD auctions\n" if DEBUG_UNSOLD;
       } # if
     if ($iCount <= 0)
       {
@@ -929,7 +929,7 @@ sub unsold_auctions
       $self->_add_error("Did not find master <TABLE> for UNSOLD section.  ");
       last PARSE_UNSOLD_SECTION;
       } # if
-    print STDERR " +   ancestor <TABLE> is ==", $oTable->as_HTML, "==\n" if DEBUG_UNSOLD;
+    print STDERR " DDD   ancestor <TABLE> is ==", $oTable->as_HTML, "==\n" if DEBUG_UNSOLD;
     # The heart of the matter is in the n-th table over from this one:
     my $iTable = 2;
     do
@@ -950,7 +950,7 @@ sub unsold_auctions
       $self->_add_error("Did not find slave <TABLE> for UNSOLD section.  ");
       last PARSE_UNSOLD_SECTION;
       } # if
-    print STDERR " +   n-th TABLE sibling of ancestor <TABLE> is ==", $oTable->as_HTML, "==\n" if DEBUG_UNSOLD;
+    print STDERR " DDD   n-th TABLE sibling of ancestor <TABLE> is ==", $oTable->as_HTML, "==\n" if DEBUG_UNSOLD;
     my @aoTR = $oTable->look_down('_tag' => 'tr');
  TR:
     while (my $oTR = shift @aoTR)
@@ -960,7 +960,7 @@ sub unsold_auctions
       # Got a row containing an auction.  Actually they are pairs of
       # rows; one row has the auction title, the next row has all the
       # details.
-      print STDERR " +   <TR> containing unsold auction title ==", $oTR->as_HTML, "==\n" if DEBUG_UNSOLD;
+      print STDERR " DDD   <TR> containing unsold auction title ==", $oTR->as_HTML, "==\n" if DEBUG_UNSOLD;
       my $oA = $oTR->look_down('_tag' => 'a');
       next TR unless ref $oA;
       # Make sure this is really an auction title/link:
@@ -971,12 +971,12 @@ sub unsold_auctions
       my $sTitle = $oA->as_text;
       $sTitle =~ s![\s\t\r\n]+\Z!!;
       $oWEL->title($sTitle);
-      print STDERR " +     title ==$sTitle==\n" if DEBUG_UNSOLD;
+      print STDERR " DDD     title ==$sTitle==\n" if DEBUG_UNSOLD;
       $oTD = $oA->look_up('_tag' => 'td');
       next TR unless ref $oTD;
       $oTD = $oTD->left;
       next TR unless ref $oTD;
-      print STDERR " +     <TD> containing Item# ==", $oTD->as_HTML, "==\n" if DEBUG_UNSOLD;
+      print STDERR " DDD     <TD> containing Item# ==", $oTD->as_HTML, "==\n" if DEBUG_UNSOLD;
       $s = $oTD->as_text;
       # Delete all but numbers:
       $s =~ tr!0123456789!!dc;
@@ -1008,13 +1008,13 @@ sub _get_user_email_OLD
   {
   my $self = shift;
   my ($sUserID, $iAuctionID) = @_;
-  DEBUG_EMAIL && _debug(" + get_user_email($sUserID,$iAuctionID)\n");
+  DEBUG_EMAIL && _debug(" DDD get_user_email($sUserID,$iAuctionID)\n");
 
   # <form name="contactmember" method="post" style="margin: 0;" action="http://contact.ebay.com/ws1/eBayISAPI.dll"><input type="hidden" name="MfcISAPICommand" value="ReturnUserEmail"><input type="hidden" name="requested" value="watto2000"><input type="hidden" name="frm" value="284"><input type="hidden" name="iid" value="2993844956"><input type="hidden" name="de" value="off"><input type="hidden" name="redirect" value="0"><input type="submit" name="contactsubmit" value="Contact Member"></form>
   my $sURL = 'http://contact.ebay.com/ws1/eBayISAPI.dll?MfcISAPICommand=ReturnUserEmail&requested=__USER__&frm=284&iid=__AUCTION__&de=off&redirect=0';
   $sURL =~ s!__USER__!$sUserID!e;
   $sURL =~ s!__AUCTION__!$iAuctionID!e;
-  DEBUG_EMAIL && _debug(" +   url ==$sURL==\n");
+  DEBUG_EMAIL && _debug(" DDD   url ==$sURL==\n");
   my $sPage = $self->fetch_any_ebay_page($sURL, 'contact');
   if ($sPage =~ m!\shref="mailto:(.+?)"!)
     {
@@ -1033,7 +1033,7 @@ sub cookie_jar
   {
   my $self = shift;
   my $arg = shift() || 0;
-  DEBUG_FUNC && _debug(" + Ebay::Session::c_jar($arg)\n");
+  DEBUG_FUNC && _debug(" DDD Ebay::Session::c_jar($arg)\n");
   if ($arg)
     {
     # If argument is given, replace current jar:
@@ -1057,7 +1057,7 @@ You need to set the cookie_jar to $self->cookie_jar.
 sub user_agent
   {
   my $self = shift;
-  DEBUG_FUNC && _debug(" + Ebay::Session::user_agent()\n");
+  DEBUG_FUNC && _debug(" DDD Ebay::Session::user_agent()\n");
   if (! ref $self->{_user_agent})
     {
     my $ua = WWW::Search::_load_env_useragent();
